@@ -1,7 +1,7 @@
 # Local imports.
 from dock_pane_toggle_group import DockPaneToggleGroup
-from schema import GroupSchema, MenuSchema, MenuBarSchema, ToolBarSchema, \
-     SGroup, SMenu, SMenuBar, SToolBar
+from schema import ActionSchema, GroupSchema, MenuSchema, MenuBarSchema, \
+    ToolBarSchema, SGroup, SMenu, SMenuBar, SToolBar
 from schema_addition import SchemaAddition
 from task_action import CentralPaneAction, DockPaneAction, EditorAction, \
      TaskAction, TaskWindowAction
