@@ -1,6 +1,6 @@
 # Enthought library imports.
 from traits.api import HasTraits, Instance
-from traitsui.api import UI, ViewElement
+from traitsui.api import UI
 
 # Local imports.
 from editor import Editor
@@ -13,14 +13,22 @@ class TraitsEditor(Editor):
     #### TraitsEditor interface ###############################################
 
     # The model object to view. If not specified, the editor is used instead.
-    obj = Instance(HasTraits)
-
-    # An (optional) view for use if a model object is specfied.
-    obj_view = Instance(ViewElement)
+    model = Instance(HasTraits)
 
     # The UI object associated with the Traits view, if it has been constructed.
     ui = Instance(UI)
 
+    ###########################################################################
+    # 'HasTraits' interface.
+    ###########################################################################
+
+    def trait_context(self):
+        """ Use the model object for the Traits UI context, if appropriate.
+        """
+        if self.model:
+            return { 'object': self.model, 'editor': self }
+        return super(TraitsEditor, self).trait_context()
+
     ###########################################################################
     # 'IEditor' interface.
     ###########################################################################
@@ -28,9 +36,7 @@ class TraitsEditor(Editor):
     def create(self, parent):
         """ Create and set the toolkit-specific contents of the editor.
         """
-        obj = self.obj if self.obj else self
-        view = self.obj_view if self.obj and self.obj_view else None
-        self.ui = obj.edit_traits(view=view, kind='subpanel', parent=parent)
+        self.ui = self.edit_traits(kind='subpanel', parent=parent)
         self.control = self.ui.control
 
     def destroy(self):
