@@ -23,7 +23,8 @@ from pyface.qt import QtCore, QtGui
 from pygments.lexers import PythonLexer
 
 # Enthought library imports.
-from traits.api import Event, implements
+from traits.api import Event, provides
+from traits.util.clean_strings import python_name
 
 # Local imports.
 from code_editor.pygments_highlighter import PygmentsHighlighter
@@ -37,12 +38,12 @@ from widget import Widget
 # 'PythonShell' class:
 #-------------------------------------------------------------------------------
 
+@provides(IPythonShell)
 class PythonShell(MPythonShell, Widget):
     """ The toolkit specific implementation of a PythonShell.  See the
     IPythonShell interface for the API documentation.
     """
 
-    implements(IPythonShell)
 
     #### 'IPythonShell' interface #############################################
 
@@ -65,6 +66,9 @@ class PythonShell(MPythonShell, Widget):
         # Set up to be notified whenever a Python statement is executed:
         self.control.executed.connect(self._on_command_executed)
 
+        # Handle dropped objects.
+        _DropEventEmitter(self.control).signal.connect(self._on_obj_drop)
+
     #--------------------------------------------------------------------------
     # 'IPythonShell' interface
     #--------------------------------------------------------------------------
@@ -85,6 +89,32 @@ class PythonShell(MPythonShell, Widget):
     def _create_control(self, parent):
         return PyfacePythonWidget(self, parent)
 
+    #--------------------------------------------------------------------------
+    # 'Private' interface.
+    #--------------------------------------------------------------------------
+
+    def _on_obj_drop(self, obj):
+        """ Handle dropped objects and add to interpreter local namespace. """
+        # If we can't create a valid Python identifier for the name of an
+        # object we use this instead.
+        name = 'dragged'
+
+        if hasattr(obj, 'name') \
+           and isinstance(obj.name, basestring) and len(obj.name) > 0:
+            py_name = python_name(obj.name)
+
+            # Make sure that the name is actually a valid Python identifier.
+            try:
+                if eval(py_name, {py_name : True}):
+                    name = py_name
+            except Exception:
+                pass
+
+        self.control.interpreter.locals[name] = obj
+        self.control.execute(name)
+        self.control._control.setFocus()
+
+
 #-------------------------------------------------------------------------------
 # 'PythonWidget' class:
 #-------------------------------------------------------------------------------
@@ -92,10 +122,10 @@ class PythonShell(MPythonShell, Widget):
 class PythonWidget(HistoryConsoleWidget):
     """ A basic in-process Python interpreter.
     """
-    
+
     # Emitted when a command has been executed in the interpeter.
     executed = QtCore.Signal()
-    
+
     #--------------------------------------------------------------------------
     # 'object' interface
     #--------------------------------------------------------------------------
@@ -299,12 +329,12 @@ class PythonWidget(HistoryConsoleWidget):
         """ Attempts to execute file with 'path'. If 'hidden', no output is
             shown.
         """
-        self.execute('execfile("%s")' % path, hidden=hidden)
+        self.execute('execfile(%s)' % repr(path), hidden=hidden)
 
     def reset(self):
         """ Resets the widget to its initial state. Similar to ``clear``, but
             also re-writes the banner.
-        """ 
+        """
         self._reading = False
         self._highlighter.highlighting_on = False
 
@@ -355,7 +385,7 @@ class PythonWidget(HistoryConsoleWidget):
                     cursor.movePosition(QtGui.QTextCursor.Left,
                                         n=len(context[-1]))
                     self._complete_with_items(cursor, completions)
-    
+
     def _get_banner(self):
         """ Gets a banner to display at the beginning of a session.
         """
@@ -369,7 +399,7 @@ class PythonWidget(HistoryConsoleWidget):
         """
         if cursor is None:
             cursor = self._get_cursor()
-        cursor.movePosition(QtGui.QTextCursor.StartOfBlock, 
+        cursor.movePosition(QtGui.QTextCursor.StartOfBlock,
                             QtGui.QTextCursor.KeepAnchor)
         text = cursor.selection().toPlainText()
         return self._completion_lexer.get_context(text)
@@ -512,13 +542,51 @@ class PyfacePythonWidget(PythonWidget):
 
         mods = event.modifiers()
         self._pyface_widget.key_pressed = KeyPressedEvent(
-            alt_down     = ((mods & QtCore.Qt.AltModifier) == 
+            alt_down     = ((mods & QtCore.Qt.AltModifier) ==
                             QtCore.Qt.AltModifier),
-            control_down = ((mods & QtCore.Qt.ControlModifier) == 
+            control_down = ((mods & QtCore.Qt.ControlModifier) ==
                             QtCore.Qt.ControlModifier),
-            shift_down   = ((mods & QtCore.Qt.ShiftModifier) == 
+            shift_down   = ((mods & QtCore.Qt.ShiftModifier) ==
                             QtCore.Qt.ShiftModifier),
             key_code     = kcode,
             event        = event)
 
         super(PyfacePythonWidget, self).keyPressEvent(event)
+
+
+#-------------------------------------------------------------------------------
+# '_DropEventFilter' class:
+#-------------------------------------------------------------------------------
+
+class _DropEventEmitter(QtCore.QObject):
+    """ Handle object drops on widget. """
+    signal = QtCore.Signal(object)
+
+    def __init__(self, widget):
+        QtCore.QObject.__init__(self, widget)
+        self.widget = widget
+
+        widget.setAcceptDrops(True)
+        widget.installEventFilter(self)
+
+    def eventFilter(self, source, event):
+        """ Handle drop events on widget. """
+        typ = event.type()
+        if typ == QtCore.QEvent.DragEnter:
+            if hasattr(event.mimeData(), 'instance'):
+                # It is pymimedata and has instance data
+                obj = event.mimeData().instance()
+                if obj is not None:
+                    event.accept()
+                    return True
+
+        elif typ == QtCore.QEvent.Drop:
+            if hasattr(event.mimeData(), 'instance'):
+                # It is pymimedata and has instance data
+                obj = event.mimeData().instance()
+                if obj is not None:
+                    self.signal.emit(obj)
+                    event.accept()
+                    return True
+
+        return QtCore.QObject.eventFilter(self, source, event)
