@@ -57,7 +57,7 @@ class WorkbenchWindowLayout(MWorkbenchWindowLayout):
 
     #### Private interface ####################################################
 
-    # The widget that implements the editor area.  We keep (and use) this
+    # The widget that provides the editor area.  We keep (and use) this
     # separate reference because we can't always assume that it has been set to
     # be the main window's central widget.
     _qt4_editor_area = Instance(SplitTabWidget)
@@ -332,6 +332,12 @@ class WorkbenchWindowLayout(MWorkbenchWindowLayout):
         if not new and not editor == self.window.active_editor:
             self._qt4_editor_area.setTabTextColor(editor.control, QtCore.Qt.red)
 
+    @on_trait_change('window:active_editor')
+    def _qt4_active_editor_changed(self, old, new):
+        """ Handle change of active editor """
+        # Reset tab title to foreground color
+        self._qt4_editor_area.setTabTextColor(new.control)
+
     def _qt4_view_focus_changed(self, old, new):
         """ Handle the change of focus for a view. """
 
@@ -497,6 +503,8 @@ class WorkbenchWindowLayout(MWorkbenchWindowLayout):
             dw.setObjectName(view.id)
             dw.connect(dw.toggleViewAction(), QtCore.SIGNAL('toggled(bool)'),
                     self._qt4_handle_dock_visibility)
+            dw.connect(dw, QtCore.SIGNAL('visibilityChanged(bool)'),
+                    self._qt4_handle_dock_visibility)
 
             # Save the dock window.
             view._qt4_dock = dw
@@ -550,7 +558,11 @@ class WorkbenchWindowLayout(MWorkbenchWindowLayout):
             except AttributeError:
                 continue
 
-            if dw.toggleViewAction() is dw.sender():
+            sender = dw.sender()
+            if (sender is dw.toggleViewAction() or
+                sender in dw.children()):
+                # Toggling the action or pressing the close button on
+                # the view
                 v.visible = checked
 
     def _qt4_monitor(self, control):
