@@ -33,7 +33,7 @@ except ImportError:
 # Enthought library imports.
 from pyface.action.api import MenuBarManager, StatusBarManager
 from pyface.action.api import ToolBarManager
-from traits.api import implements, Instance, List, Unicode
+from traits.api import Instance, List, provides, Unicode
 from pyface.i_application_window import IApplicationWindow
 from pyface.i_application_window import MApplicationWindow
 from pyface.image_resource import ImageResource
@@ -43,12 +43,12 @@ from window import Window
 from system_metrics import SystemMetrics
 
 
+@provides(IApplicationWindow)
 class ApplicationWindow(MApplicationWindow, Window):
     """ The toolkit specific implementation of an ApplicationWindow.  See the
     IApplicationWindow interface for the API documentation.
     """
 
-    implements(IApplicationWindow)
 
     #### 'IApplicationWindow' interface #######################################
 
@@ -183,6 +183,11 @@ class ApplicationWindow(MApplicationWindow, Window):
 
         return control
 
+    def destroy(self):
+        if self.control and AUI:
+            self._aui_manager.UnInit()
+        super(ApplicationWindow, self).destroy()
+
     ###########################################################################
     # Private interface.
     ###########################################################################
