@@ -8,7 +8,7 @@ import logging
 from pyface.api import ApplicationWindow, GUI
 from traits.api import Callable, Constant, Delegate, Event, Instance
 from traits.api import List, Str, Tuple, Unicode, Vetoable
-from traits.api import implements, on_trait_change
+from traits.api import on_trait_change, provides
 
 # Local imports.
 from i_editor import IEditor
